// ============================================================================
// ==                                                                        ==
// == AMDiS - Adaptive multidimensional simulations                          ==
// ==                                                                        ==
// ==  http://www.amdis-fem.org                                              ==
// ==                                                                        ==
// ============================================================================
//
// Software License for AMDiS
//
// Copyright (c) 2010 Dresden University of Technology 
// All rights reserved.
// Authors: Simon Vey, Thomas Witkowski et al.
//
// This file is part of AMDiS
//
// See also license.opensource.txt in the distribution.



/** \file Boundary.h */

#ifndef AMDIS_BOUNDARY_H
#define AMDIS_BOUNDARY_H

#include <map>
#include "Global.h"

namespace AMDiS {

  /// Contains boundary constants
  typedef enum {
    INTERIOR = 0,   /**< interior => no boundary (b = 0) */
    DIRICHLET = 1,  /**< dirichlet boundary (b > 0) */
    NEUMANN = -1,   /**< neumann boundary  (-100 < b < 0) */
    ROBIN = -100    /**< robin boundary (b <= -100) */
  } BoundaryConstants;

  /// Type specifier for the different boundary types 
  typedef signed int BoundaryType;

  BoundaryType newBound(BoundaryType oldBound, BoundaryType newBound);

}

#endif
